@@ -1,16 +1,17 @@
 package Exception::Class;
 
-use 5.005;
+use 5.008001;
 
 use strict;
-use vars qw($VERSION $BASE_EXC_CLASS %CLASSES);
 
 use Scalar::Util qw(blessed);
 
-
+our $BASE_EXC_CLASS;
 BEGIN { $BASE_EXC_CLASS ||= 'Exception::Class::Base'; }
 
-$VERSION = '1.26';
+our $VERSION = '1.27';
+
+our %CLASSES;
 
 sub import
 {
@@ -293,8 +294,7 @@ sub _initialize
     my $self = shift;
     my %p = @_ == 1 ? ( error => $_[0] ) : @_;
 
-    # Try to get something useful in there (I hope).  Or just give up.
-    $self->{message} = $p{message} || $p{error} || $! || '';
+    $self->{message} = $p{message} || $p{error} || '';
 
     $self->{show_trace} = $p{show_trace} if exists $p{show_trace};
 
@@ -680,8 +680,8 @@ an array.
 =item * throw( error => $error )
 
 This method creates a new object with the given error message.  If no
-error message is given, C<$!> is used.  It then die's with this object
-as its argument.
+error message is given, this will be an empty string.  It then die's
+with this object as its argument.
 
 This method also takes a C<show_trace> parameter which indicates
 whether or not the particular exception object being created should
